@@ -304,13 +304,13 @@ mockVocabRef <- function(backend = "data_frame") {
                                     stratum_5_name = NA,
                                     is_default = NA,
                                     category = NA )
-  achillesResults <- dplyr::tibble(analysis_id = c(401, 401),
-                             stratum_1 = c(4, 5),
+  achillesResults <- dplyr::tibble(analysis_id = c(401, 401, 401),
+                             stratum_1 = c(4, 5, 9),
                              stratum_2 = NA,
                              stratum_3 = NA,
                              stratum_4 = NA,
                              stratum_5 = NA,
-                             count_value = c(400, 200))
+                             count_value = c(400, 200, 100))
   achillesResultsDist <- dplyr::tibble(analysis_id = 1,
                                        stratum_1 = NA,
                                        stratum_2 = NA,
