@@ -186,6 +186,9 @@ fetchAchillesCounts <- function(cdm, analysisId, conceptId = NULL){
       dplyr::filter(.data$concept_id %in%  .env$conceptId)
   }
 
+  # the same code might appear in multiple tables so we will sum them
   analyses %>%
+    dplyr::group_by(.data$concept_id) |>
+    dplyr::summarise(n = sum(.data$n, na.rm = TRUE)) |>
     dplyr::mutate(n = as.integer(.data$n))
 }
