@@ -161,14 +161,6 @@ test_that("tests with mock db", {
       includeDescendants = FALSE,
       includeAncestor = TRUE
     )
-    expect_true(all(c(
-      "concept_id", "concept_name",
-      "domain_id", "vocabulary_id", "found_from", "ingredient_concept_id",
-      "amount_value", "amount_unit_concept_id",
-      "numerator_value", "numerator_unit_concept_id", "denominator_value",
-      "denominator_unit_concept_id", "box_size", "dose_form"
-    ) %in%
-      names(codes)))
     expect_true(codes$concept_id == "10")
 
     # search for drug and condition
@@ -180,14 +172,6 @@ test_that("tests with mock db", {
       includeDescendants = TRUE,
       includeAncestor = TRUE
     )
-    expect_true(all(c(
-      "concept_id", "concept_name",
-      "domain_id", "vocabulary_id", "found_from", "ingredient_concept_id",
-      "amount_value", "amount_unit_concept_id",
-      "numerator_value", "numerator_unit_concept_id", "denominator_value",
-      "denominator_unit_concept_id", "box_size", "dose_form"
-    ) %in%
-      names(codes)))
     expect_true(any(codes$concept_id %in% "10"))
 
     ## Edge cases
@@ -216,6 +200,14 @@ test_that("tests with mock db", {
     )
     expect_true(nrow(codes) == 0)
 
+    codes <- getCandidateCodes(
+      cdm = cdm,
+      keywords = "a", exclude = "a",
+      standardConcept = c("Standard"),
+      includeDescendants = FALSE
+    )
+    expect_true(nrow(codes) == 0)
+
     # domain that doesn´t exist
     codes <- getCandidateCodes(
       cdm = cdm,
@@ -312,3 +304,31 @@ test_that("tests with mock db - multiple domains", {
     }
   }
 })
+
+test_that("tests with eunomia", {
+
+  skip_on_cran()
+  skip_on_ci()
+  db <- DBI::dbConnect(duckdb::duckdb(),
+                       dbdir = CDMConnector::eunomia_dir())
+  cdm <- CDMConnector::cdm_from_con(
+    con = db,
+    cdm_schema = "main",
+    write_schema = "main"
+  )
+
+ codes <- getCandidateCodes(cdm=cdm,
+                  keywords= "sinusitis",
+                  domains = c("Condition", "observation"),
+                  searchInSynonyms = TRUE,
+                  searchNonStandard = TRUE,
+                  includeAncestor = TRUE)
+
+ expect_true(sum(is.na(codes$concept_name)) == 0)
+
+ expect_equal(codes |>
+   dplyr::pull("concept_id"),
+ unique(codes |>
+   dplyr::pull("concept_id")))
+
+})
